@@ -32,6 +32,7 @@ __all__ = [
     'TestDBusPauseResume',
     'TestDBusProgress',
     'TestDBusRegressions',
+    'TestDBusUseCache',
     ]
 
 
@@ -42,7 +43,7 @@ import shutil
 import unittest
 
 from contextlib import ExitStack
-from datetime import datetime, timedelta
+from datetime import datetime
 from dbus.exceptions import DBusException
 from functools import partial
 from systemimage.bindings import DBusClient
@@ -50,8 +51,8 @@ from systemimage.config import Configuration
 from systemimage.helpers import safe_remove
 from systemimage.reactor import Reactor
 from systemimage.testing.helpers import (
-    copy, make_http_server, setup_index, setup_keyring_txz, setup_keyrings,
-    sign)
+    copy, find_dbus_process, make_http_server, setup_index, setup_keyring_txz,
+    setup_keyrings, sign)
 from systemimage.testing.nose import SystemImagePlugin
 
 
@@ -124,6 +125,9 @@ class PausingReactor(Reactor):
 class _TestBase(unittest.TestCase):
     """Base class for all DBus testing."""
 
+    # For unittest's assertMultiLineEqual().
+    maxDiff = None
+
     # Override this to start the DBus server in a different testing mode.
     mode = None
 
@@ -136,21 +140,17 @@ class _TestBase(unittest.TestCase):
 
     @classmethod
     def tearDownClass(cls):
-        bus = dbus.SystemBus()
-        service = bus.get_object('com.canonical.SystemImage', '/Service')
-        iface = dbus.Interface(service, 'com.canonical.SystemImage')
-        iface.Exit()
-        # 2013-07-30 BAW: This sucks but there's no way to know exactly when
-        # the process has exited, because we cannot know the pid of the
-        # system-image-dbus process, which is our grandchild.  Just keep
-        # pinging the server until it stops responding.
-        until = datetime.now() + timedelta(seconds=60)
-        while datetime.now() < until:
-            time.sleep(0.2)
-            try:
-                iface.Exit()
-            except DBusException:
-                break
+        # Try to find the system-image-dbus process matching the current ini
+        # file used by the controller.  We'll use this to ensure that the
+        # process has exited.
+        process = find_dbus_process(SystemImagePlugin.controller.ini_path)
+        if process is not None:
+            bus = dbus.SystemBus()
+            service = bus.get_object('com.canonical.SystemImage', '/Service')
+            iface = dbus.Interface(service, 'com.canonical.SystemImage')
+            iface.Exit()
+            # Wait for the process to exit, but only for a little while.
+            process.wait(60)
         # Clear out the temporary directory.
         config = Configuration()
         config.load(SystemImagePlugin.controller.ini_path)
@@ -270,7 +270,12 @@ class _LiveTesting(_TestBase):
         sign(index_path, 'device-signing.gpg')
         setup_index(index_file, serverdir, 'device-signing.gpg')
 
-    def _set_build(self, version):
+    def _touch_build(self, version):
+        # Unlike the touch_build() helper, this one uses our own config object
+        # rather than the global one.   It's not worth messing with
+        # touch_build() to generalize it.
+        assert 0 <= version < (1 << 16), (
+            'old style version number: {}'.format(version))
         with open(self.config.system.build_file, 'w', encoding='utf-8') as fp:
             print(version, file=fp)
 
@@ -299,7 +304,7 @@ class TestDBusCheckForUpdate(_LiveTesting):
          error_reason) = reactor.signals[0]
         self.assertTrue(is_available)
         self.assertFalse(downloading)
-        self.assertEqual(available_version, '20130600')
+        self.assertEqual(available_version, '1600')
         self.assertEqual(update_size, 314572800)
         # This is the first update applied.
         self.assertEqual(last_update_date, 'Unknown')
@@ -319,7 +324,7 @@ class TestDBusCheckForUpdate(_LiveTesting):
          error_reason) = reactor.signals[0]
         self.assertTrue(is_available)
         self.assertTrue(downloading)
-        self.assertEqual(available_version, '20130600')
+        self.assertEqual(available_version, '1600')
         self.assertEqual(update_size, 314572800)
         # This is the first update applied.
         self.assertEqual(last_update_date, 'Unknown')
@@ -328,7 +333,7 @@ class TestDBusCheckForUpdate(_LiveTesting):
 
     def test_no_update_available(self):
         # Our device is newer than the version that's available.
-        self._set_build(20130701)
+        self._touch_build(1701)
         # Give /etc/ubuntu-build a predictable mtime.
         timestamp = int(datetime(2013, 8, 1, 10, 11, 12).timestamp())
         os.utime(self.config.system.build_file, (timestamp, timestamp))
@@ -347,7 +352,7 @@ class TestDBusCheckForUpdate(_LiveTesting):
     def test_last_update_date(self):
         # Pretend the device got a previous update.  Now, there's no update
         # available, but the date of the last update is provided in the signal.
-        self._set_build(20130701)
+        self._touch_build(1701)
         # Fake that there was a previous update.
         timestamp = int(datetime(2013, 1, 20, 12, 1, 45).timestamp())
         channel_ini = os.path.join(
@@ -435,7 +440,7 @@ unmount system
     def test_nothing_to_auto_download(self):
         # We're auto-downloading, but there's no update available.
         self.download_always()
-        self._set_build(20130701)
+        self._touch_build(1701)
         self.assertFalse(os.path.exists(self.command_file))
         reactor = SignalCapturingReactor('UpdateAvailableStatus')
         reactor.run(self.iface.CheckForUpdate)
@@ -495,7 +500,7 @@ unmount system
     def test_nothing_to_manually_download(self):
         # We're manually downloading, but there's no update available.
         self.download_manually()
-        self._set_build(20130701)
+        self._touch_build(1701)
         self.assertFalse(os.path.exists(self.command_file))
         reactor = SignalCapturingReactor('UpdateAvailableStatus')
         reactor.run(self.iface.CheckForUpdate)
@@ -532,8 +537,31 @@ unmount system
         self.assertEqual(len(reactor.signals), 1)
         failure_count, last_reason = reactor.signals[0]
         self.assertEqual(failure_count, 1)
+        self.assertEqual(last_reason[:17], 'FileNotFoundError')
+
+    def test_duplicate_destinations(self):
+        # A faulty index.json might specify that two different urls yield the
+        # same local destination file.  This is a bug on the server and the
+        # client cannot perform an update.
+        self.download_manually()
+        self._prepare_index('index_23.json')
+        reactor = SignalCapturingReactor('UpdateAvailableStatus')
+        reactor.run(self.iface.CheckForUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        (is_available, downloading, available_version, update_size,
+         last_update_date,
+         #descriptions,
+         error_reason) = reactor.signals[0]
+        self.assertTrue(is_available)
+        self.assertFalse(downloading)
+        reactor = SignalCapturingReactor('UpdateFailed')
+        reactor.run(self.iface.DownloadUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        failure_count, last_reason = reactor.signals[0]
+        self.assertEqual(failure_count, 1)
         # Don't count on a specific error message.
-        self.assertNotEqual(last_reason, '')
+        self.assertEqual(
+            last_reason[:46], 'systemimage.download.DuplicateDestinationError')
 
 
 class TestDBusApply(_LiveTesting):
@@ -546,7 +574,10 @@ class TestDBusApply(_LiveTesting):
         self.assertFalse(os.path.exists(self.reboot_log))
         reactor = SignalCapturingReactor('UpdateDownloaded')
         reactor.run(self.iface.CheckForUpdate)
-        self.iface.ApplyUpdate()
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertTrue(reactor.signals[0])
         with open(self.reboot_log, encoding='utf-8') as fp:
             reboot = fp.read()
         self.assertEqual(reboot, '/sbin/reboot -f recovery')
@@ -554,13 +585,13 @@ class TestDBusApply(_LiveTesting):
     def test_reboot_no_update(self):
         # There's no update to reboot to.
         self.assertFalse(os.path.exists(self.reboot_log))
-        self._set_build(20130701)
+        self._touch_build(1701)
         reactor = SignalCapturingReactor('UpdateAvailableStatus')
         reactor.run(self.iface.CheckForUpdate)
-        response = self.iface.ApplyUpdate()
-        # Let's not count on the exact response, except that success returns
-        # the empty string.
-        self.assertNotEqual(response, '')
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertFalse(reactor.signals[0][0])
         self.assertFalse(os.path.exists(self.reboot_log))
 
     def test_reboot_after_update_failed(self):
@@ -577,7 +608,10 @@ class TestDBusApply(_LiveTesting):
         self.assertEqual(failure_count, 1)
         self.assertNotEqual(reason, '')
         # The reboot fails, so we get an error message.
-        self.assertNotEqual(self.iface.ApplyUpdate(), '')
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertFalse(reactor.signals[0][0])
 
     def test_auto_download_cancel(self):
         # While automatically downloading, cancel the update.
@@ -589,6 +623,7 @@ class TestDBusApply(_LiveTesting):
         self.assertTrue(reactor.got_update_failed)
 
     def test_exit(self):
+        # There is a D-Bus method to exit the server immediately.
         self.iface.Exit()
         self.assertRaises(DBusException, self.iface.Info)
         # Re-establish a new connection.
@@ -597,7 +632,10 @@ class TestDBusApply(_LiveTesting):
         self.iface = dbus.Interface(service, 'com.canonical.SystemImage')
         # There's no update to apply, so we'll get an error string instead of
         # the empty string for this call.  But it will restart the server.
-        self.assertNotEqual(self.iface.ApplyUpdate(), '')
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertFalse(reactor.signals[0][0])
 
     def test_cancel_while_not_downloading(self):
         # If we call CancelUpdate() when we're not downloading anything, no
@@ -738,7 +776,10 @@ class TestDBusMockUpdateAutoSuccess(_TestBase):
             self.assertEqual(percentage, i)
             self.assertEqual(eta, 50 - (i * 0.5))
         self.assertTrue(reactor.downloaded)
-        self.assertEqual(self.iface.ApplyUpdate(), '')
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertTrue(reactor.signals[0])
 
     def test_scenario_2(self):
         # Like scenario 1, but with PauseDownload called during the downloads.
@@ -867,7 +908,10 @@ class TestDBusMockUpdateManualSuccess(_TestBase):
             self.assertEqual(percentage, i)
             self.assertEqual(eta, 50 - (i * 0.5))
         self.assertTrue(reactor.downloaded)
-        self.assertEqual(self.iface.ApplyUpdate(), '')
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertTrue(reactor.signals[0])
 
 
 class TestDBusMockUpdateFailed(_TestBase):
@@ -933,8 +977,10 @@ class TestDBusMockFailApply(_TestBase):
         ##     }])
         self.assertEqual(error_reason, '')
         self.assertTrue(reactor.downloaded)
-        self.assertEqual(self.iface.ApplyUpdate(),
-                         'Not enough battery, you need to plug in your phone')
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertFalse(bool(reactor.signals[0][0]))
 
 
 class TestDBusMockFailResume(_TestBase):
@@ -1059,7 +1105,7 @@ class TestDBusClient(_LiveTesting):
 
     def test_check_for_no_update(self):
         # There is no update available.
-        self._set_build(20130701)
+        self._touch_build(1701)
         self._client.check_for_update()
         self.assertFalse(self._client.is_available)
         self.assertFalse(self._client.downloaded)
@@ -1283,7 +1329,7 @@ class TestDBusInfo(_TestBase):
 class TestDBusInfoNoDetails(_LiveTesting):
     def test_info_no_version_details(self):
         # .Info() where there is no channel.ini with version details.
-        self._set_build(45)
+        self._touch_build(45)
         timestamp = datetime(2022, 8, 1, 4, 45, 45).timestamp()
         os.utime(self.config.system.build_file, (timestamp, timestamp))
         buildno, device, channel, last_update, details = self.iface.Info()
@@ -1297,7 +1343,7 @@ class TestDBusInfoNoDetails(_LiveTesting):
 class TestDBusProgress(_LiveTesting):
     def test_progress(self):
         self.download_always()
-        self._set_build(0)
+        self._touch_build(0)
         reactor = SignalCapturingReactor('UpdateAvailableStatus')
         reactor.run(self.iface.CheckForUpdate)
         self.assertEqual(len(reactor.signals), 1)
@@ -1333,7 +1379,7 @@ class TestDBusPauseResume(_LiveTesting):
 
     def test_pause(self):
         self.download_manually()
-        self._set_build(0)
+        self._touch_build(0)
         reactor = SignalCapturingReactor('UpdateAvailableStatus')
         reactor.run(self.iface.CheckForUpdate)
         self.assertEqual(len(reactor.signals), 1)
@@ -1349,7 +1395,121 @@ class TestDBusPauseResume(_LiveTesting):
         reactor = SignalCapturingReactor('UpdateFailed')
         reactor.run(self.iface.DownloadUpdate, timeout=60)
         self.assertEqual(len(reactor.signals), 1)
-        # We've gotten one error and the first file that filed is 5.txt.
+        # We've gotten one error and the first file that failed is 5.txt.
         failure_count, last_error = reactor.signals[0]
         self.assertEqual(failure_count, 1)
-        self.assertEqual(os.path.basename(last_error), '5.txt')
+        # Watch out for the trailing newline.
+        self.assertEqual(os.path.basename(last_error[:-1]), '5.txt')
+
+
+class TestDBusUseCache(_LiveTesting):
+    # See LP: #1217098
+
+    def test_use_cache(self):
+        # We run the D-Bus service once through to download all the relevant
+        # files.  Then we kill the service before performing the reboot, and
+        # try to do another download.  The second one should only try to
+        # download the ancillary files (i.e. channels.json, index.json,
+        # keyrings), but not the data files.
+        self.download_always()
+        self._touch_build(0)
+        reactor = SignalCapturingReactor('UpdateAvailableStatus')
+        reactor.run(self.iface.CheckForUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        # There's one boolean argument to the result.
+        (is_available, downloading, available_version, update_size,
+         last_update_date,
+         #descriptions,
+         error_reason) = reactor.signals[0]
+        self.assertTrue(is_available)
+        self.assertTrue(downloading)
+        # Now, wait for the UpdateDownloaded signal.
+        reactor = SignalCapturingReactor('UpdateDownloaded')
+        reactor.run()
+        self.assertEqual(len(reactor.signals), 1)
+        config = Configuration()
+        config.load(SystemImagePlugin.controller.ini_path)
+        self.assertEqual(set(os.listdir(config.updater.cache_partition)),
+                         set((
+                             '5.txt',
+                             '5.txt.asc',
+                             '6.txt',
+                             '6.txt.asc',
+                             '7.txt',
+                             '7.txt.asc',
+                             'device-signing.tar.xz',
+                             'device-signing.tar.xz.asc',
+                             'image-master.tar.xz',
+                             'image-master.tar.xz.asc',
+                             'image-signing.tar.xz',
+                             'image-signing.tar.xz.asc',
+                             'ubuntu_command',
+                             )))
+        # To prove that the data files are not downloaded again, let's
+        # actually remove them from the server.
+        for dirpath, dirnames, filenames in os.walk(
+                SystemImagePlugin.controller.serverdir):
+            for filename in filenames:
+                if filename.endswith('.txt') or filename.endswith('.txt.asc'):
+                    os.remove(os.path.join(dirpath, filename))
+        # As extra proof, get the mtime in nanoseconds for the .txt and
+        # .txt.asc files.
+        mtimes = {}
+        for filename in os.listdir(config.updater.cache_partition):
+            path = os.path.join(config.updater.cache_partition, filename)
+            if filename.endswith('.txt') or filename.endswith('.txt.asc'):
+                mtimes[filename] = os.stat(path).st_mtime_ns
+        # Don't issue the reboot.  Instead, kill the services, which throws
+        # away all state, but does not delete the cached files.
+        # Re-establish a new connection.
+        process = find_dbus_process(SystemImagePlugin.controller.ini_path)
+        if process is not None:
+            self.iface.Exit()
+            process.wait(60)
+        bus = dbus.SystemBus()
+        service = bus.get_object('com.canonical.SystemImage', '/Service')
+        self.iface = dbus.Interface(service, 'com.canonical.SystemImage')
+        # Now, if we just apply the update, it will succeed, since it knows
+        # that the cached files are valid.
+        reactor = SignalCapturingReactor('Rebooting')
+        reactor.run(self.iface.ApplyUpdate)
+        self.assertEqual(len(reactor.signals), 1)
+        self.assertTrue(reactor.signals[0])
+        self.assertEqual(set(os.listdir(config.updater.cache_partition)),
+                         set((
+                             '5.txt',
+                             '5.txt.asc',
+                             '6.txt',
+                             '6.txt.asc',
+                             '7.txt',
+                             '7.txt.asc',
+                             'device-signing.tar.xz',
+                             'device-signing.tar.xz.asc',
+                             'image-master.tar.xz',
+                             'image-master.tar.xz.asc',
+                             'image-signing.tar.xz',
+                             'image-signing.tar.xz.asc',
+                             # This file exists because reboot is mocked out
+                             # in the dbus tests to just write to a log file.
+                             'reboot.log',
+                             'ubuntu_command',
+                             )))
+        for filename in os.listdir(config.updater.cache_partition):
+            path = os.path.join(config.updater.cache_partition, filename)
+            if filename.endswith('.txt') or filename.endswith('.txt.asc'):
+                self.assertEqual(mtimes[filename], os.stat(path).st_mtime_ns)
+        # Make sure the ubuntu_command file has the full update.
+        path = os.path.join(config.updater.cache_partition, 'ubuntu_command')
+        with open(path, 'r', encoding='utf-8') as fp:
+            command = fp.read()
+        self.assertMultiLineEqual(command, """\
+load_keyring image-master.tar.xz image-master.tar.xz.asc
+load_keyring image-signing.tar.xz image-signing.tar.xz.asc
+load_keyring device-signing.tar.xz device-signing.tar.xz.asc
+format system
+mount system
+update 6.txt 6.txt.asc
+update 7.txt 7.txt.asc
+update 5.txt 5.txt.asc
+unmount system
+""")
